Package: logcondens
Type: Package
Title: Estimate a Log-Concave Probability Density from Iid Observations
Version: 2.1.9
Date: 2026-04-26
Authors@R: 
    c(person(given = "Kaspar", family = "Rufibach", role = c("aut", "cre"), email = "kaspar.rufibach@gmail.com"),
    person(given = "Duembgen", family = "Lutz", role = "aut", email = "duembgen@stat.unibe.ch"))
Maintainer: Kaspar Rufibach <kaspar.rufibach@gmail.com>
Depends: R (>= 2.10)
Imports: ks, graphics, stats
Description: Given independent and identically distributed observations X(1), ..., X(n), compute the maximum likelihood estimator (MLE) of a density as well as a smoothed version of it under the assumption that the density is log-concave, see Rufibach (2007) and Duembgen and Rufibach (2009). The main function of the package is 'logConDens' that allows computation of the log-concave MLE and its smoothed version. In addition, we provide functions to compute (1) the value of the density and distribution function estimates (MLE and smoothed) at a given point (2) the characterizing functions of the estimator, (3) to sample from the estimated distribution, (5) to compute a two-sample permutation test based on log-concave densities, (6) the ROC curve based on log-concave estimates within cases and controls, including confidence intervals for given values of false positive fractions (7) computation of a confidence interval for the value of the true density at a fixed point. Finally, three datasets that have been used to illustrate log-concave density estimation are made available.
License: GPL (>= 2)
URL: http://www.kasparrufibach.ch ,
        https://www.imsv.unibe.ch/about_us/staff/prof_dr_duembgen_lutz/index_eng.html
NeedsCompilation: no
Packaged: 2026-04-26 16:34:34 UTC; kaspa
Author: Kaspar Rufibach [aut, cre],
  Duembgen Lutz [aut]
Repository: CRAN
Date/Publication: 2026-04-26 17:00:03 UTC
