## which functions shall be accessible by the users?
export(
activeSetLogCon,
confIntBootLogConROC_t0,
etaphi,
evaluateLogConDens,
icmaLogCon,
intECDF,
intF,
isoMean,
J00,
J10,
J11,
J20,
Lhat_eta,
Local_LL,
Local_LL_all,
LocalCoarsen,
LocalConvexity,
LocalExtend,
LocalF,
LocalMLE,
LocalNormalize,
LocalVariance,
logConDens,
logConROC,
logconTwoSample,
maxDiffCDF,
MLE,
phieta,
plot.dlc,
preProcess,
Q00,
qloglin,
quadDeriv,
quantilesLogConDens,
rlogcon,
robust,
ROCx,
summary.dlc,
logConCI,
ftilde,
c2hat
)

importFrom(ks, hscv, kdde, hlscv, hpi, hns)
importFrom(graphics, abline, legend, lines, mtext, par, plot, rug, segments)
importFrom(stats, dnorm, integrate, pnorm, quantile, rnorm, runif, uniroot)

S3method(summary, dlc, summary.dlc)
S3method(plot, dlc, plot.dlc)
